From cd741af899dbd4b17ca966aa366924b166c09ba0 Mon Sep 17 00:00:00 2001
From: Manuel Gunther <siebenkopf@googlemail.com>
Date: Wed, 4 May 2016 16:30:44 -0600
Subject: [PATCH] Updated documentation

---
 bob/bio/face/preprocessor/Base.py | 4 ++--
 doc/conf.py                       | 2 +-
 doc/index.rst                     | 1 +
 3 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/doc/conf.py b/doc/conf.py
index 4915c472..e410c650 100644
--- a/doc/conf.py
+++ b/doc/conf.py
@@ -246,7 +246,7 @@ autodoc_default_flags = ['members', 'inherited-members', 'show-inheritance']
 
 # For inter-documentation mapping:
 from bob.extension.utils import link_documentation
-intersphinx_mapping = link_documentation(['python', 'numpy', 'bob.bio.gmm', 'bob.bio.csu', 'bob.db.lfw'])
+intersphinx_mapping = link_documentation(['python', 'numpy', 'bob.bio.gmm', 'bob.bio.video', 'bob.bio.csu', 'bob.db.lfw'])
 
 
 def skip(app, what, name, obj, skip, options):
diff --git a/doc/index.rst b/doc/index.rst
index 1682a360..be7e8c2c 100644
--- a/doc/index.rst
+++ b/doc/index.rst
@@ -20,6 +20,7 @@ This includes:
 Additionally, a set of baseline algorithms are defined, which integrate well with the two other ``bob.bio`` packages:
 
 * :ref:`bob.bio.gmm <bob.bio.gmm>` defines algorithms based on Gaussian mixture models
+* :ref:`bob.bio.video <bob.bio.video>` uses face recognition algorithms in video frames
 * :ref:`bob.bio.csu <bob.bio.csu>` provides wrapper classes of the `CSU Face Recognition Resources <http://www.cs.colostate.edu/facerec>`_ (only Python 2.7 compatible)
 
 For more detailed information about the structure of the ``bob.bio`` packages, please refer to the documentation of :ref:`bob.bio.base <bob.bio.base>`.
diff --git a/bob/bio/face/preprocessor/Base.py b/bob/bio/face/preprocessor/Base.py
index 9a939368..28bd2066 100644
--- a/bob/bio/face/preprocessor/Base.py
+++ b/bob/bio/face/preprocessor/Base.py
@@ -63,7 +63,7 @@ class Base (Preprocessor):
     """data_type(image) -> image
 
     Converts the given image into the data type specified in the constructor of this class.
     If no data type was specified, no conversion is performed.
 
     **Parameters:**
 
@@ -75,7 +75,7 @@ class Base (Preprocessor):
     image : 2D or 3D :py:class:`numpy.ndarray`
       The image converted to the desired data type, if any.
     """
-    if self.dtype is not None:
+    if self.dtype is not None and image is not None:
       image = image.astype(self.dtype)
     return image
 
@@ -63,7 +63,7 @@ class Base (Preprocessor):
 
     Converts the given image into the data type specified in the constructor of this class.
-    If no data type was specified, no conversion is performed.
+    If no data type was specified, or the ``image`` is ``None``, no conversion is performed.
 
     **Parameters:**
-- 
GitLab